summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authordoccvs <doccvs@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2000-07-17 17:43:06 +0000
committerdoccvs <doccvs@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2000-07-17 17:43:06 +0000
commitb143115a14f2ec214cb40c41e6da28c5eb466eec (patch)
treeecf6d319c2f338be7c560f9dbe9cbcd61d8602c2
parent86bc8bbf0418f66068362bb3da59c556388939d9 (diff)
downloadATCD-b143115a14f2ec214cb40c41e6da28c5eb466eec.tar.gz
ChangeLogTag: Mon Jul 17 10:41:08 2000 Priyanka Gontla <pgontla@ece.uci.edu>
-rw-r--r--TAO/ChangeLogs/ChangeLog-02a21
-rw-r--r--TAO/tao/IIOP_Profile.cpp23
2 files changed, 32 insertions, 12 deletions
diff --git a/TAO/ChangeLogs/ChangeLog-02a b/TAO/ChangeLogs/ChangeLog-02a
index 3a8000e2de2..0a51a19249b 100644
--- a/TAO/ChangeLogs/ChangeLog-02a
+++ b/TAO/ChangeLogs/ChangeLog-02a
@@ -1,3 +1,24 @@
+Mon Jul 17 10:41:08 2000 Priyanka Gontla <pgontla@ece.uci.edu>
+
+ * tao/IIOP_Profile.cpp: Updated the default port number to '2809'.
+
+Fri Jul 14 15:11:19 2000 Priyanka Gontla <pgontla@ece.uci.edu>
+
+ * tao/ior_corbaloc/CORBALOC_Parser.cpp:
+ The implementation now supports multiple endpoints correctly.
+
+Fri Jul 14 10:57:17 2000 Priyanka Gontla <pgontla@ece.uci.edu>
+
+ * tao/IIOP_Profile.cpp: Made some format changes and added some
+ debug statements.
+
+Thu Jul 13 16:25:25 2000 Priyanka Gontla <pgontla@ece.uci.edu>
+
+ * tao/IIOP_Profile.cpp:
+ Modified so that the default port is <683> and the default host
+ is the local host instead of raising an exception when an empty
+ host or port is passed.
+
Tue Jul 11 14:16:17 2000 Priyanka Gontla <pgontla@ece.uci.edu>
* tests/ior_corbaloc/corbaloc.idl:
diff --git a/TAO/tao/IIOP_Profile.cpp b/TAO/tao/IIOP_Profile.cpp
index a76bef11372..510158fb1f5 100644
--- a/TAO/tao/IIOP_Profile.cpp
+++ b/TAO/tao/IIOP_Profile.cpp
@@ -270,7 +270,7 @@ TAO_IIOP_Profile::parse_string (const char *string,
}
// The default port number.
- const char def_port [] = ":683";
+ const char def_port [] = ":2809";
// Length of port.
CORBA::ULong length = 0;
@@ -282,37 +282,36 @@ TAO_IIOP_Profile::parse_string (const char *string,
CORBA::ULong length_cp =
ACE_OS::strlen ((const char *)okd) + sizeof (def_port);
- char *cp = CORBA::string_alloc (length_cp);
-
+ CORBA::String_var cp = CORBA::string_alloc (length_cp);
+
if (cp_pos == 0)
-
{
// No host/port delimiter! Dont raise an exception. Use the
// default port No. 683
ACE_OS::strcpy (cp, def_port);
ACE_OS::strcat (cp, okd);
length =
- ACE_OS::strlen ((const char *)cp) -
+ ACE_OS::strlen (cp.in ()) -
ACE_OS::strlen ((const char *)okd) -
1;
length_host =
ACE_OS::strlen (start) +
sizeof (def_port) -
- ACE_OS::strlen (cp) -1;
+ ACE_OS::strlen (cp.in ()) -1;
}
else
{
// The port is specified:
- cp = cp_pos;
- length = okd - (cp + 1);
- length_host = cp - start;
+ cp = (const char *)cp_pos;
+ length = ACE_OS::strlen (cp.in ()) - ACE_OS::strlen ((const char *)okd) + 1;
+ length_host = ACE_OS::strlen ((const char *)start) - ACE_OS::strlen (cp.in ());
}
-
+
CORBA::String_var tmp = CORBA::string_alloc (length);
- ACE_OS::strncpy (tmp.inout (), cp + 1, length);
+ ACE_OS::strncpy (tmp.inout (), cp.in () + 1, length);
tmp[length] = '\0';
this->port_ = (CORBA::UShort) ACE_OS::atoi (tmp.in ());
@@ -282,37 +282,36 @@ TAO_IIOP_Profile::parse_string (const char *string,
{
// No host/port delimiter! Dont raise an exception. Use the
- // default port No. 683
+ // default port No. 2809
ACE_OS::strcpy (cp, def_port);
ACE_OS::strcat (cp, okd);